=======
Lock-up
=======

SWAN lock-up commands

.. autosummary::
    :nosignatures:
    :toctree: _generated/

    rompy_swan.components.lockup.COMPUTE
    rompy_swan.components.lockup.HOTFILE
    rompy_swan.components.lockup.COMPUTE_STAT
    rompy_swan.components.lockup.COMPUTE_NONSTAT
    rompy_swan.components.lockup.STOP
